@@ -5,7 +5,7 @@ use warnings;
 require Algorithm::SAT::Backtracking;
 use Storable qw(dclone);
 use Carp qw(croak);
-our $VERSION = "0.07";
+our $VERSION = "0.08";
 
 # Boolean expression builder.  Note that the connector for clauses is `OR`;
 # so, when calling the instance methods `xor`, `and`, and `or`, the clauses
@@ -168,5 +168,9 @@ it under the same terms as Perl itself.
 
 mudler E<lt>mudler@dark-lab.netE<gt>
 
+=head1 SEE ALSO
+
+L<Algorithm::SAT::Backtracking>, L<Algorithm::SAT::Backtracking::DPLL>, L<Algorithm::SAT::Backtracking::Ordered>, L<Algorithm::SAT::Backtracking::Ordered::DPLL>
+
 =cut
 
